@@ -103,9 +103,12 @@ class ExceptionLogger(QTreeWidget):
             return
         
         if exceptionMessage == '':
-            itm.setText(0, "{0}".format(exceptionType))
+            text = "{0}".format(exceptionType)
         else:
-            itm.setText(0, "{0}, {1}".format(exceptionType, exceptionMessage))
+            text = "{0}, {1}".format(exceptionType, exceptionMessage)
+        
+        itm.setText(0, text)
+        itm.setToolTip(0, text)
         
         # now add the call stack, most recent call first
         for entry in stackTrace:
