@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -206,7 +206,7 @@ class E5ModelMenu(QMenu):
             
             icon = parent.data(Qt.DecorationRole)
             if icon == NotImplemented or icon is None:
-                icon = UI.PixmapCache.getIcon("defaultIcon.png")
+                icon = UI.PixmapCache.getIcon("defaultIcon")
             modelMenu.setIcon(icon)
             if parentMenu is not None:
                 parentMenu.addMenu(modelMenu).setData(v)
@@ -246,7 +246,7 @@ class E5ModelMenu(QMenu):
         """
         icon = idx.data(Qt.DecorationRole)
         if icon == NotImplemented or icon is None:
-            icon = UI.PixmapCache.getIcon("defaultIcon.png")
+            icon = UI.PixmapCache.getIcon("defaultIcon")
         action = self.makeAction(icon, idx.data(), self)
         action.setStatusTip(idx.data(self.__statusBarTextRole))
         
@@ -266,7 +266,10 @@ class E5ModelMenu(QMenu):
         """
         fm = QFontMetrics(self.font())
         if self.__maxWidth == -1:
-            self.__maxWidth = fm.width('m') * 30
+            try:
+                self.__maxWidth = fm.horizontalAdvance("m") * 30
+            except AttributeError:
+                self.__maxWidth = fm.width('m') * 30
         smallText = fm.elidedText(text, Qt.ElideMiddle, self.__maxWidth)
         
         return QAction(icon, smallText, parent)
