@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -45,22 +45,22 @@ class E5SslCertificatesDialog(QDialog, Ui_E5SslCertificatesDialog):
         self.setupUi(self)
         
         self.serversViewButton.setIcon(
-            UI.PixmapCache.getIcon("certificates.png"))
+            UI.PixmapCache.getIcon("certificates"))
         self.serversDeleteButton.setIcon(
-            UI.PixmapCache.getIcon("certificateDelete.png"))
+            UI.PixmapCache.getIcon("certificateDelete"))
         self.serversExportButton.setIcon(
-            UI.PixmapCache.getIcon("certificateExport.png"))
+            UI.PixmapCache.getIcon("certificateExport"))
         self.serversImportButton.setIcon(
-            UI.PixmapCache.getIcon("certificateImport.png"))
+            UI.PixmapCache.getIcon("certificateImport"))
         
         self.caViewButton.setIcon(
-            UI.PixmapCache.getIcon("certificates.png"))
+            UI.PixmapCache.getIcon("certificates"))
         self.caDeleteButton.setIcon(
-            UI.PixmapCache.getIcon("certificateDelete.png"))
+            UI.PixmapCache.getIcon("certificateDelete"))
         self.caExportButton.setIcon(
-            UI.PixmapCache.getIcon("certificateExport.png"))
+            UI.PixmapCache.getIcon("certificateExport"))
         self.caImportButton.setIcon(
-            UI.PixmapCache.getIcon("certificateImport.png"))
+            UI.PixmapCache.getIcon("certificateImport"))
         
         self.__populateServerCertificatesTree()
         self.__populateCaCertificatesTree()
