@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2016 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2016 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -612,7 +612,10 @@ class HexEditWidget(QAbstractScrollArea):
         @type QFont
         """
         super(HexEditWidget, self).setFont(font)
-        self.__pxCharWidth = self.fontMetrics().width("2")
+        try:
+            self.__pxCharWidth = self.fontMetrics().horizontalAdvance("2")
+        except AttributeError:
+            self.__pxCharWidth = self.fontMetrics().width("2")
         self.__pxCharHeight = self.fontMetrics().height()
         self.__pxGapAdr = self.__pxCharWidth // 2
         self.__pxGapAdrHex = self.__pxCharWidth
@@ -659,10 +662,9 @@ class HexEditWidget(QAbstractScrollArea):
         @param ch byte to insert
         @type int in the range 0x00 to 0xff
         """
-        assert ch in range(0, 256)
-        
-        self.__undoStack.insert(pos, ch)
-        self.__refresh()
+        if ch in range(0, 256):
+            self.__undoStack.insert(pos, ch)
+            self.__refresh()
     
     def remove(self, pos, length=1):
         """
@@ -685,10 +687,9 @@ class HexEditWidget(QAbstractScrollArea):
         @param ch byte to replace with
         @type int in the range 0x00 to 0xff
         """
-        assert ch in range(0, 256)
-        
-        self.__undoStack.overwrite(pos, ch)
-        self.__refresh()
+        if ch in range(0, 256):
+            self.__undoStack.overwrite(pos, ch)
+            self.__refresh()
     
     def insertByteArray(self, pos, byteArray):
         """
