@@ -39,17 +39,17 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
         super(IrcIdentitiesEditDialog, self).__init__(parent)
         self.setupUi(self)
         
-        self.addButton.setIcon(UI.PixmapCache.getIcon("plus.png"))
-        self.copyButton.setIcon(UI.PixmapCache.getIcon("editCopy.png"))
-        self.renameButton.setIcon(UI.PixmapCache.getIcon("editRename.png"))
-        self.deleteButton.setIcon(UI.PixmapCache.getIcon("minus.png"))
-        self.nicknameAddButton.setIcon(UI.PixmapCache.getIcon("plus.png"))
-        self.nicknameDeleteButton.setIcon(UI.PixmapCache.getIcon("minus.png"))
-        self.nicknameUpButton.setIcon(UI.PixmapCache.getIcon("1uparrow.png"))
+        self.addButton.setIcon(UI.PixmapCache.getIcon("plus"))
+        self.copyButton.setIcon(UI.PixmapCache.getIcon("editCopy"))
+        self.renameButton.setIcon(UI.PixmapCache.getIcon("editRename"))
+        self.deleteButton.setIcon(UI.PixmapCache.getIcon("minus"))
+        self.nicknameAddButton.setIcon(UI.PixmapCache.getIcon("plus"))
+        self.nicknameDeleteButton.setIcon(UI.PixmapCache.getIcon("minus"))
+        self.nicknameUpButton.setIcon(UI.PixmapCache.getIcon("1uparrow"))
         self.nicknameDownButton.setIcon(
-            UI.PixmapCache.getIcon("1downarrow.png"))
+            UI.PixmapCache.getIcon("1downarrow"))
         self.showPasswordButton.setIcon(
-            UI.PixmapCache.getIcon("showPassword.png"))
+            UI.PixmapCache.getIcon("showPassword"))
         
         self.__manager = manager
         
@@ -468,13 +468,13 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
         if checked:
             self.passwordEdit.setEchoMode(QLineEdit.Normal)
             self.showPasswordButton.setIcon(
-                UI.PixmapCache.getIcon("hidePassword.png"))
+                UI.PixmapCache.getIcon("hidePassword"))
             self.showPasswordButton.setToolTip(
                 self.tr("Press to hide the password"))
         else:
             self.passwordEdit.setEchoMode(QLineEdit.Password)
             self.showPasswordButton.setIcon(
-                UI.PixmapCache.getIcon("showPassword.png"))
+                UI.PixmapCache.getIcon("showPassword"))
             self.showPasswordButton.setToolTip(
                 self.tr("Press to show the password"))
     
