@@ -54,10 +54,10 @@ class IrcNetworkWidget(QWidget, Ui_IrcNetworkWidget):
         super(IrcNetworkWidget, self).__init__(parent)
         self.setupUi(self)
         
-        self.connectButton.setIcon(UI.PixmapCache.getIcon("ircConnect.png"))
-        self.editButton.setIcon(UI.PixmapCache.getIcon("ircConfigure.png"))
-        self.joinButton.setIcon(UI.PixmapCache.getIcon("ircJoinChannel.png"))
-        self.awayButton.setIcon(UI.PixmapCache.getIcon("ircUserPresent.png"))
+        self.connectButton.setIcon(UI.PixmapCache.getIcon("ircConnect"))
+        self.editButton.setIcon(UI.PixmapCache.getIcon("ircConfigure"))
+        self.joinButton.setIcon(UI.PixmapCache.getIcon("ircJoinChannel"))
+        self.awayButton.setIcon(UI.PixmapCache.getIcon("ircUserPresent"))
         
         self.joinButton.setEnabled(False)
         self.nickCombo.setEnabled(False)
@@ -191,14 +191,14 @@ class IrcNetworkWidget(QWidget, Ui_IrcNetworkWidget):
             # set being away
             # don't send away, if the status is already set
             self.sendData.emit("AWAY :" + awayMessage)
-            self.awayButton.setIcon(UI.PixmapCache.getIcon("ircUserAway.png"))
+            self.awayButton.setIcon(UI.PixmapCache.getIcon("ircUserAway"))
             self.__away = True
             self.away.emit(self.__away)
         elif not awayMessage and self.__away:
             # cancel being away
             self.sendData.emit("AWAY")
             self.awayButton.setIcon(
-                UI.PixmapCache.getIcon("ircUserPresent.png"))
+                UI.PixmapCache.getIcon("ircUserPresent"))
             self.__away = False
             self.away.emit(self.__away)
     
@@ -344,12 +344,12 @@ class IrcNetworkWidget(QWidget, Ui_IrcNetworkWidget):
         self.__connected = connected
         if self.__connected:
             self.connectButton.setIcon(
-                UI.PixmapCache.getIcon("ircDisconnect.png"))
+                UI.PixmapCache.getIcon("ircDisconnect"))
             self.connectButton.setToolTip(
                 self.tr("Press to disconnect from the network"))
         else:
             self.connectButton.setIcon(
-                UI.PixmapCache.getIcon("ircConnect.png"))
+                UI.PixmapCache.getIcon("ircConnect"))
             self.connectButton.setToolTip(
                 self.tr("Press to connect to the selected network"))
     
@@ -374,7 +374,7 @@ class IrcNetworkWidget(QWidget, Ui_IrcNetworkWidget):
         self.awayButton.setEnabled(registered)
         if registered:
             self.awayButton.setIcon(
-                UI.PixmapCache.getIcon("ircUserPresent.png"))
+                UI.PixmapCache.getIcon("ircUserPresent"))
             self.__away = False
     
     def __clearMessages(self):
@@ -471,22 +471,22 @@ class IrcNetworkWidget(QWidget, Ui_IrcNetworkWidget):
         """
         self.__messagesMenu = QMenu(self)
         self.__copyMessagesAct = self.__messagesMenu.addAction(
-            UI.PixmapCache.getIcon("editCopy.png"),
+            UI.PixmapCache.getIcon("editCopy"),
             self.tr("Copy"), self.__copyMessages)
         self.__messagesMenu.addSeparator()
         self.__cutAllMessagesAct = self.__messagesMenu.addAction(
-            UI.PixmapCache.getIcon("editCut.png"),
+            UI.PixmapCache.getIcon("editCut"),
             self.tr("Cut all"), self.__cutAllMessages)
         self.__copyAllMessagesAct = self.__messagesMenu.addAction(
-            UI.PixmapCache.getIcon("editCopy.png"),
+            UI.PixmapCache.getIcon("editCopy"),
             self.tr("Copy all"), self.__copyAllMessages)
         self.__messagesMenu.addSeparator()
         self.__clearMessagesAct = self.__messagesMenu.addAction(
-            UI.PixmapCache.getIcon("editDelete.png"),
+            UI.PixmapCache.getIcon("editDelete"),
             self.tr("Clear"), self.__clearMessages)
         self.__messagesMenu.addSeparator()
         self.__saveMessagesAct = self.__messagesMenu.addAction(
-            UI.PixmapCache.getIcon("fileSave.png"),
+            UI.PixmapCache.getIcon("fileSave"),
             self.tr("Save"), self.__saveMessages)
         
         self.on_messages_copyAvailable(False)
