@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2013 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -12,15 +12,10 @@ Module implementing a checker for documentation string conventions.
 # pep257.py (version 0.2.4).
 #
 
-try:
-    # Python 2
-    from StringIO import StringIO       # __IGNORE_EXCEPTION__
-except ImportError:
-    # Python 3
-    from io import StringIO             # __IGNORE_WARNING__
 import tokenize
 import ast
 import sys
+from io import StringIO
 
 try:
     ast.AsyncFunctionDef    # __IGNORE_EXCEPTION__
@@ -40,11 +35,7 @@ class DocStyleContext(object):
         @param startLine line number the context starts in the source (integer)
         @param contextType type of the context object (string)
         """
-        if sys.version_info[0] == 2:
-            stringTypes = (str, unicode)        # __IGNORE_WARNING__
-        else:
-            stringTypes = str
-        if isinstance(source, stringTypes):
+        if isinstance(source, str):
             self.__source = source.splitlines(True)
         else:
             self.__source = source[:]
@@ -132,7 +123,7 @@ class DocStyleChecker(object):
     """
     Codes = [
         "D101", "D102", "D103", "D104", "D105",
-        "D111", "D112", "D113",
+        "D111", "D112",
         "D121", "D122",
         "D130", "D131", "D132", "D133", "D134",
         "D141", "D142", "D143", "D144", "D145",
@@ -163,8 +154,6 @@ class DocStyleChecker(object):
         @keyparam docType type of the documentation strings
             (string, one of 'eric' or 'pep257')
         """
-        assert docType in ("eric", "pep257")
-        
         self.__select = tuple(select)
         self.__ignore = ('',) if select else tuple(ignore)
         self.__expected = expected[:]
@@ -215,7 +204,6 @@ class DocStyleChecker(object):
                 "docstring": [
                     (self.__checkTripleDoubleQuotes, ("D111",)),
                     (self.__checkBackslashes, ("D112",)),
-                    (self.__checkUnicode, ("D113",)),
                     (self.__checkOneLiner, ("D121",)),
                     (self.__checkIndent, ("D122",)),
                     (self.__checkSummary, ("D130",)),
@@ -255,7 +243,6 @@ class DocStyleChecker(object):
                 "docstring": [
                     (self.__checkTripleDoubleQuotes, ("D111",)),
                     (self.__checkBackslashes, ("D112",)),
-                    (self.__checkUnicode, ("D113",)),
                     (self.__checkIndent, ("D122",)),
                     (self.__checkSummary, ("D130",)),
                     (self.__checkEricEndsWithPeriod, ("D231",)),
@@ -308,7 +295,14 @@ class DocStyleChecker(object):
         if code and (self.counters[code] == 1 or self.__repeat):
             # record the issue with one based line number
             self.errors.append(
-                (self.__filename, lineNumber + 1, offset, (code, args)))
+                {
+                    "file": self.__filename,
+                    "line": lineNumber + 1,
+                    "offset": offset,
+                    "code": code,
+                    "args": args,
+                }
+            )
     
     def __reportInvalidSyntax(self):
         """
@@ -355,12 +349,6 @@ class DocStyleChecker(object):
             return
         
         source = "".join(self.__source)
-        # Check type for py2: if not str it's unicode
-        if sys.version_info[0] == 2:
-            try:
-                source = source.encode('utf-8')
-            except UnicodeError:
-                pass
         try:
             compile(source, self.__filename, 'exec', ast.PyCF_ONLY_AST)
         except (SyntaxError, TypeError):
@@ -440,62 +428,30 @@ class DocStyleChecker(object):
             summaries.append(line2)
         return summaries, lineno
     
-    if sys.version_info[0] < 3:
-        def __getArgNames(self, node):
-            """
-            Private method to get the argument names of a function node.
-            
-            @param node AST node to extract arguments names from
-            @return tuple of two list of argument names, one for arguments
-                and one for keyword arguments (tuple of list of string)
-            """
-            def unpackArgs(args):
-                """
-                Local helper function to unpack function argument names.
-                
-                @param args list of AST node arguments
-                @return list of argument names (list of string)
-                """
-                ret = []
-                for arg in args:
-                    if isinstance(arg, ast.Tuple):
-                        ret.extend(unpackArgs(arg.elts))
-                    else:
-                        ret.append(arg.id)
-                return ret
-            
-            arguments = unpackArgs(node.args.args)
-            if node.args.vararg is not None:
+    def __getArgNames(self, node):
+        """
+        Private method to get the argument names of a function node.
+        
+        @param node AST node to extract arguments names from
+        @return tuple of two list of argument names, one for arguments
+            and one for keyword arguments (tuple of list of string)
+        """
+        arguments = []
+        arguments.extend([arg.arg for arg in node.args.args])
+        if node.args.vararg is not None:
+            if sys.version_info < (3, 4, 0):
                 arguments.append(node.args.vararg)
-            kwarguments = []
-            if node.args.kwarg is not None:
+            else:
+                arguments.append(node.args.vararg.arg)
+        
+        kwarguments = []
+        kwarguments.extend([arg.arg for arg in node.args.kwonlyargs])
+        if node.args.kwarg is not None:
+            if sys.version_info < (3, 4, 0):
                 kwarguments.append(node.args.kwarg)
-            return arguments, kwarguments
-    else:
-        def __getArgNames(self, node):          # __IGNORE_WARNING__
-            """
-            Private method to get the argument names of a function node.
-            
-            @param node AST node to extract arguments names from
-            @return tuple of two list of argument names, one for arguments
-                and one for keyword arguments (tuple of list of string)
-            """
-            arguments = []
-            arguments.extend([arg.arg for arg in node.args.args])
-            if node.args.vararg is not None:
-                if sys.version_info < (3, 4, 0):
-                    arguments.append(node.args.vararg)
-                else:
-                    arguments.append(node.args.vararg.arg)
-            
-            kwarguments = []
-            kwarguments.extend([arg.arg for arg in node.args.kwonlyargs])
-            if node.args.kwarg is not None:
-                if sys.version_info < (3, 4, 0):
-                    kwarguments.append(node.args.kwarg)
-                else:
-                    kwarguments.append(node.args.kwarg.arg)
-            return arguments, kwarguments
+            else:
+                kwarguments.append(node.args.kwarg.arg)
+        return arguments, kwarguments
     
     ##################################################################
     ## Parsing functionality below
@@ -815,24 +771,6 @@ class DocStyleChecker(object):
         if "\\" in docstring and not docstring.startswith('r"""'):
             self.__error(docstringContext.start(), 0, "D112")
     
-    def __checkUnicode(self, docstringContext, context):
-        """
-        Private method to check, that all docstrings containing unicode
-        characters are surrounded by unicode triple double quotes.
-        
-        @param docstringContext docstring context (DocStyleContext)
-        @param context context of the docstring (DocStyleContext)
-        """
-        if docstringContext is None:
-            return
-        
-        docstring = docstringContext.ssource().strip()
-        if (
-            not docstring.startswith('u"""') and
-            any(ord(char) > 127 for char in docstring)
-        ):
-            self.__error(docstringContext.start(), 0, "D113")
-    
     def __checkOneLiner(self, docstringContext, context):
         """
         Private method to check, that one-liner docstrings fit on
@@ -846,7 +784,8 @@ class DocStyleChecker(object):
         
         lines = docstringContext.source()
         if len(lines) > 1:
-            nonEmptyLines = [l for l in lines if l.strip().strip('\'"')]
+            nonEmptyLines = [line for line in lines
+                             if line.strip().strip('\'"')]
             if len(nonEmptyLines) == 1:
                 modLen = len(context.indent() + '"""' +
                              nonEmptyLines[0].strip() + '"""')
@@ -872,11 +811,11 @@ class DocStyleChecker(object):
         if len(lines) == 1:
             return
         
-        nonEmptyLines = [l.rstrip() for l in lines[1:] if l.strip()]
+        nonEmptyLines = [line.rstrip() for line in lines[1:] if line.strip()]
         if not nonEmptyLines:
             return
         
-        indent = min(len(l) - len(l.strip()) for l in nonEmptyLines)
+        indent = min(len(line) - len(line.strip()) for line in nonEmptyLines)
         if context.contextType() == "module":
             expectedIndent = 0
         else:
@@ -1503,6 +1442,3 @@ class DocStyleChecker(object):
                 if firstWord != 'public':
                     self.__error(docstringContext.start() + lineNumber, 0,
                                  "D232", 'public')
-
-#
-# eflag: noqa = M702
