@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2015 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2015 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -151,14 +151,9 @@ class MiscellaneousChecker(object):
         self.__pep3101FormatRegex = re.compile(
             r'^(?:[^\'"]*[\'"][^\'"]*[\'"])*\s*%|^\s*%')
         
-        if sys.version_info >= (3, 0):
-            import builtins
-            self.__builtins = [b for b in dir(builtins)
-                               if b not in self.BuiltinsWhiteList]
-        else:
-            import __builtin__
-            self.__builtins = [b for b in dir(__builtin__)
-                               if b not in self.BuiltinsWhiteList]
+        import builtins
+        self.__builtins = [b for b in dir(builtins)
+                           if b not in self.BuiltinsWhiteList]
 
         # statistics counters
         self.counters = {}
@@ -261,7 +256,14 @@ class MiscellaneousChecker(object):
         if code and (self.counters[code] == 1 or self.__repeat):
             # record the issue with one based line number
             self.errors.append(
-                (self.__filename, lineNumber + 1, offset, (code, args)))
+                {
+                    "file": self.__filename,
+                    "line": lineNumber + 1,
+                    "offset": offset,
+                    "code": code,
+                    "args": args,
+                }
+            )
     
     def __reportInvalidSyntax(self):
         """
@@ -285,13 +287,6 @@ class MiscellaneousChecker(object):
         @rtype ast.AST
         """
         source = "".join(self.__source)
-        # Check type for py2: if not str it's unicode
-        if sys.version_info[0] == 2:
-            try:
-                source = source.encode('utf-8')
-            except UnicodeError:
-                pass
-        
         return compile(source, self.__filename, 'exec', ast.PyCF_ONLY_AST)
     
     def run(self):
@@ -526,7 +521,7 @@ class MiscellaneousChecker(object):
         visitor.visit(self.__tree)
         for node in visitor.nodes:
             text = node.s
-            if sys.version_info[0] > 2 and isinstance(text, bytes):
+            if isinstance(text, bytes):
                 try:
                     text = text.decode(coding)
                 except UnicodeDecodeError:
@@ -704,22 +699,13 @@ class MiscellaneousChecker(object):
             elif any(isinstance(node, functionDef)
                      for functionDef in functionDefs):
                 # (asynchronous) function definition
-                if sys.version_info >= (3, 0):
-                    for arg in node.args.args:
-                        if (
-                            isinstance(arg, ast.arg) and
-                            arg.arg in self.__builtins
-                        ):
-                            self.__error(arg.lineno - 1, arg.col_offset,
-                                         "M132", arg.arg)
-                else:
-                    for arg in node.args.args:
-                        if (
-                            isinstance(arg, ast.Name) and
-                            arg.id in self.__builtins
-                        ):
-                            self.__error(arg.lineno - 1, arg.col_offset,
-                                         "M132", arg.id)
+                for arg in node.args.args:
+                    if (
+                        isinstance(arg, ast.arg) and
+                        arg.arg in self.__builtins
+                    ):
+                        self.__error(arg.lineno - 1, arg.col_offset,
+                                     "M132", arg.arg)
     
     def __checkComprehensions(self):
         """
@@ -955,23 +941,20 @@ class MiscellaneousChecker(object):
         """
         Private method to check use of naive datetime functions.
         """
-        if sys.version_info[0] >= 3:
-            # this check is only performed for Python 3
-            
-            # step 1: generate an augmented node tree containing parent info
-            #         for each child node
-            tree = self.__generateTree()
-            for node in ast.walk(tree):
-                for childNode in ast.iter_child_nodes(node):
-                    childNode._dtCheckerParent = node
-            
-            # step 2: perform checks and report issues
-            visitor = DateTimeVisitor()
-            visitor.visit(tree)
-            for violation in visitor.violations:
-                node = violation[0]
-                reason = violation[1]
-                self.__error(node.lineno - 1, node.col_offset, reason)
+        # step 1: generate an augmented node tree containing parent info
+        #         for each child node
+        tree = self.__generateTree()
+        for node in ast.walk(tree):
+            for childNode in ast.iter_child_nodes(node):
+                childNode._dtCheckerParent = node
+        
+        # step 2: perform checks and report issues
+        visitor = DateTimeVisitor()
+        visitor.visit(tree)
+        for violation in visitor.violations:
+            node = violation[0]
+            reason = violation[1]
+            self.__error(node.lineno - 1, node.col_offset, reason)
     
     def __checkSysVersion(self):
         """
@@ -1377,16 +1360,12 @@ class BugBearVisitor(ast.NodeVisitor):
         @param node reference to the node to be processed
         @type ast.Call
         """
-        if sys.version_info >= (3, 0):
-            validPaths = ("six", "future.utils", "builtins")
-            methodsDict = {
-                "M521": ("iterkeys", "itervalues", "iteritems", "iterlists"),
-                "M522": ("viewkeys", "viewvalues", "viewitems", "viewlists"),
-                "M523": ("next",),
-            }
-        else:
-            validPaths = ()
-            methodsDict = {}
+        validPaths = ("six", "future.utils", "builtins")
+        methodsDict = {
+            "M521": ("iterkeys", "itervalues", "iteritems", "iterlists"),
+            "M522": ("viewkeys", "viewvalues", "viewitems", "viewlists"),
+            "M523": ("next",),
+        }
         
         if isinstance(node.func, ast.Attribute):
             for code, methods in methodsDict.items():
@@ -1443,13 +1422,12 @@ class BugBearVisitor(ast.NodeVisitor):
         """
         callPath = list(composeCallPath(node))
         
-        if '.'.join(callPath) == 'sys.maxint' and sys.version_info >= (3, 0):
+        if '.'.join(callPath) == 'sys.maxint':
             self.violations.append((node, "M504"))
         
         elif (
             len(callPath) == 2 and
-            callPath[1] == 'message' and
-            sys.version_info >= (2, 6)
+            callPath[1] == 'message'
         ):
             name = callPath[0]
             for elem in reversed(self.__nodeStack[:-1]):
@@ -1468,7 +1446,7 @@ class BugBearVisitor(ast.NodeVisitor):
             # By using 'hasattr' below we're ignoring starred arguments, slices
             # and tuples for simplicity.
             assignTargets = {t.id for t in node.targets if hasattr(t, 'id')}
-            if '__metaclass__' in assignTargets and sys.version_info >= (3, 0):
+            if '__metaclass__' in assignTargets:
                 self.violations.append((node, "M524"))
         
         elif len(node.targets) == 1:
@@ -1493,6 +1471,17 @@ class BugBearVisitor(ast.NodeVisitor):
         
         self.generic_visit(node)
     
+    def visit_AsyncFor(self, node):
+        """
+        Public method to handle 'for' statements.
+        
+        @param node reference to the node to be processed
+        @type ast.AsyncFor
+        """
+        self.__checkForM507(node)
+        
+        self.generic_visit(node)
+    
     def visit_Assert(self, node):
         """
         Public method to handle 'assert' statements.
@@ -1624,6 +1613,7 @@ class ReturnVisitor(ast.NodeVisitor):
         
         self.__stack = []
         self.violations = []
+        self.__loopCount = 0
     
     @property
     def assigns(self):
@@ -1658,6 +1648,44 @@ class ReturnVisitor(ast.NodeVisitor):
         """
         return self.__stack[-1][ReturnVisitor.Returns]
     
+    def visit_For(self, node):
+        """
+        Public method to handle a for loop.
+        
+        @param node reference to the for node to handle
+        @type ast.For
+        """
+        self.__visitLoop(node)
+    
+    def visit_AsyncFor(self, node):
+        """
+        Public method to handle an async for loop.
+        
+        @param node reference to the async for node to handle
+        @type ast.AsyncFor
+        """
+        self.__visitLoop(node)
+    
+    def visit_While(self, node):
+        """
+        Public method to handle a while loop.
+        
+        @param node reference to the while node to handle
+        @type ast.While
+        """
+        self.__visitLoop(node)
+    
+    def __visitLoop(self, node):
+        """
+        Private method to handle loop nodes.
+        
+        @param node reference to the loop node to handle
+        @type ast.For, ast.AsyncFor or ast.While
+        """
+        self.__loopCount += 1
+        self.generic_visit(node)
+        self.__loopCount -= 1
+    
     def __visitWithStack(self, node):
         """
         Private method to traverse a given function node using a stack.
@@ -1712,10 +1740,18 @@ class ReturnVisitor(ast.NodeVisitor):
         """
         if not self.__stack:
             return
-        
-        for target in node.targets:
-            self.__visitAssignTarget(target)
+
         self.generic_visit(node.value)
+        
+        target = node.targets[0]
+        if (
+            isinstance(target, ast.Tuple) and
+            not isinstance(node.value, ast.Tuple)
+        ):
+            # skip unpacking assign
+            return
+        
+        self.__visitAssignTarget(target)
     
     def visit_Name(self, node):
         """
@@ -1739,7 +1775,7 @@ class ReturnVisitor(ast.NodeVisitor):
                 self.__visitAssignTarget(elt)
             return
         
-        if isinstance(node, ast.Name):
+        if not self.__loopCount and isinstance(node, ast.Name):
             self.assigns[node.id].append(node.lineno)
             return
         
@@ -1777,14 +1813,26 @@ class ReturnVisitor(ast.NodeVisitor):
         @param node reference to the node to check
         @type ast.AST
         @return flag indicating the node contains a None value
+        @rtype bool
         """
-        if sys.version_info[0] > 2:
-            return (
-                AstUtilities.isNameConstant(node) and
-                AstUtilities.getValue(node) is None
-            )
-        else:
-            return isinstance(node, ast.Name) and node.id == "None"
+        return (
+            AstUtilities.isNameConstant(node) and
+            AstUtilities.getValue(node) is None
+        )
+    
+    def __isFalse(self, node):
+        """
+        Private method to check, if a node value is False.
+        
+        @param node reference to the node to check
+        @type ast.AST
+        @return flag indicating the node contains a False value
+        @rtype bool
+        """
+        return (
+            AstUtilities.isNameConstant(node) and
+            AstUtilities.getValue(node) is False
+        )
     
     def __resultExists(self):
         """
@@ -1832,18 +1880,20 @@ class ReturnVisitor(ast.NodeVisitor):
             self.__checkImplicitReturn(node.orelse[-1])
             return
         
-        if isinstance(node, ast.For) and node.orelse:
+        if isinstance(node, (ast.For, ast.AsyncFor)) and node.orelse:
             self.__checkImplicitReturn(node.orelse[-1])
             return
         
-        if isinstance(node, ast.With):
+        if isinstance(node, (ast.With, ast.AsyncWith)):
             self.__checkImplicitReturn(node.body[-1])
             return
         
+        if isinstance(node, ast.Assert) and self.__isFalse(node.test):
+            return
+        
         try:
             okNodes = (ast.Return, ast.Raise, ast.While, ast.Try)
         except AttributeError:
-            # Py2
             okNodes = (ast.Return, ast.Raise, ast.While)
         if not isinstance(node, okNodes):
             self.violations.append((node, "M833"))
@@ -2316,4 +2366,4 @@ class SysVersionVisitor(ast.NodeVisitor):
         self.generic_visit(node)
 
 #
-# eflag: noqa = M702, M891
+# eflag: noqa = M891
