@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -65,13 +65,6 @@ class SyntaxCheckerPlugin(QObject):
         path = os.path.join(ericPath, 'Plugins', 'CheckerPlugins',
                             'SyntaxChecker')
         
-        self.syntaxCheckService.addLanguage(
-            'Python2', 'Python2', path, 'SyntaxCheck',
-            self.__getPythonOptions,
-            lambda: Preferences.getPython("PythonExtensions"),
-            self.__translateSyntaxCheck,
-            self.syntaxCheckService.serviceErrorPy2)
-        
         self.syntaxCheckService.addLanguage(
             'Python3', 'Python3', path, 'SyntaxCheck',
             self.__getPythonOptions,
@@ -79,7 +72,6 @@ class SyntaxCheckerPlugin(QObject):
             self.__translateSyntaxCheck,
             self.syntaxCheckService.serviceErrorPy3)
         
-        # Jasy isn't yet compatible to Python2
         self.syntaxCheckService.addLanguage(
             'JavaScript', 'Python3', path,
             'jsCheckSyntax',
@@ -88,6 +80,26 @@ class SyntaxCheckerPlugin(QObject):
             lambda fn, problems:
                 self.syntaxCheckService.syntaxChecked.emit(fn, problems),
             self.syntaxCheckService.serviceErrorJavaScript)
+        
+        # YAML syntax check via Python3
+        self.syntaxCheckService.addLanguage(
+            'YAML', 'Python3', path,
+            'yamlCheckSyntax',
+            lambda: [],  # No options
+            lambda: ['.yml', '.yaml'],
+            lambda fn, problems:
+                self.syntaxCheckService.syntaxChecked.emit(fn, problems),
+            self.syntaxCheckService.serviceErrorYAML)
+        
+        # JSON syntax check via Python3
+        self.syntaxCheckService.addLanguage(
+            'JSON', 'Python3', path,
+            'jsonCheckSyntax',
+            lambda: [],  # No options
+            lambda: ['.json'],
+            lambda fn, problems:
+                self.syntaxCheckService.syntaxChecked.emit(fn, problems),
+            self.syntaxCheckService.serviceErrorJSON)
 
     def __initialize(self):
         """
