@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -48,8 +48,8 @@ class FileDialogWizard(QObject):
         super(FileDialogWizard, self).__init__(ui)
         self.__ui = ui
         
-        # PyQt4 or PyQt5
-        self.__pyqtRe = re.compile(r"(?:import|from)\s+PyQt([45])")
+        # PyQt5
+        self.__pyqtRe = re.compile(r"(?:import|from)\s+PyQt([5])")
 
     def activate(self):
         """
@@ -124,7 +124,7 @@ class FileDialogWizard(QObject):
         @param editor reference to the current editor
         @type Editor
         @param variant variant of code to be generated
-            (-1 = E5FileDialog, 0 = unknown, 4 = PyQt4, 5 = PyQt5)
+            (-1 = E5FileDialog, 0 = unknown, 5 = PyQt5)
         @type int
         @return the generated code (string)
         """
@@ -166,7 +166,7 @@ class FileDialogWizard(QObject):
                     # unknown
                     dialogVariant = 0
                 else:
-                    # PyQt4 or PyQt5
+                    # PyQt5
                     dialogVariant = int(match.group(1))
             elif variant == "E5FileDialog":
                 # E5FileDialog
