@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -40,10 +40,10 @@ class GitNewProjectOptionsDialog(QDialog, Ui_GitNewProjectOptionsDialog):
         
         self.__vcs = vcs
         
-        self.projectDirButton.setIcon(UI.PixmapCache.getIcon("open.png"))
-        self.vcsUrlButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        self.projectDirButton.setIcon(UI.PixmapCache.getIcon("open"))
+        self.vcsUrlButton.setIcon(UI.PixmapCache.getIcon("open"))
         self.vcsUrlClearHistoryButton.setIcon(
-            UI.PixmapCache.getIcon("editDelete.png"))
+            UI.PixmapCache.getIcon("editDelete"))
         
         vcsUrlHistory = self.__vcs.getPlugin().getPreferences(
             "RepositoryUrlHistory")
