@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2017 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2017 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -43,10 +43,10 @@ class GitSubmoduleAddDialog(QDialog, Ui_GitSubmoduleAddDialog):
         self.__vcs = vcs
         self.__repodir = repodir
         
-        self.submoduleDirButton.setIcon(UI.PixmapCache.getIcon("open.png"))
-        self.submoduleUrlButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        self.submoduleDirButton.setIcon(UI.PixmapCache.getIcon("open"))
+        self.submoduleUrlButton.setIcon(UI.PixmapCache.getIcon("open"))
         self.submoduleUrlClearHistoryButton.setIcon(
-            UI.PixmapCache.getIcon("editDelete.png"))
+            UI.PixmapCache.getIcon("editDelete"))
         
         submoduleUrlHistory = self.__vcs.getPlugin().getPreferences(
             "RepositoryUrlHistory")
