@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2016 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2016 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to edit the history modification plan.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtCore import pyqtSlot, QCoreApplication
 from PyQt5.QtWidgets import QDialog, QTreeWidgetItem, QComboBox
@@ -88,8 +87,8 @@ class HgHisteditPlanEditor(QDialog, Ui_HgHisteditPlanEditor):
         super(HgHisteditPlanEditor, self).__init__(parent)
         self.setupUi(self)
         
-        self.upButton.setIcon(UI.PixmapCache.getIcon("1uparrow.png"))
-        self.downButton.setIcon(UI.PixmapCache.getIcon("1downarrow.png"))
+        self.upButton.setIcon(UI.PixmapCache.getIcon("1uparrow"))
+        self.downButton.setIcon(UI.PixmapCache.getIcon("1downarrow"))
         
         self.planTreeWidget.headerItem().setText(
             self.planTreeWidget.columnCount(), "")
