@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -67,7 +67,7 @@ class LargefilesProjectHelper(HgExtensionProjectHelper):
         
         self.hgLfPullAct = E5Action(
             self.tr('Pull Large Files'),
-            UI.PixmapCache.getIcon("vcsUpdate.png"),
+            UI.PixmapCache.getIcon("vcsUpdate"),
             self.tr('Pull Large Files'),
             0, 0, self, 'mercurial_pull_largefiles')
         self.hgLfPullAct.setStatusTip(self.tr(
@@ -83,7 +83,7 @@ class LargefilesProjectHelper(HgExtensionProjectHelper):
         
         self.hgLfSummaryAct = E5Action(
             self.tr('Show Summary'),
-            UI.PixmapCache.getIcon("vcsSummary.png"),
+            UI.PixmapCache.getIcon("vcsSummary"),
             self.tr('Show summary...'),
             0, 0, self, 'mercurial_summary_largefiles')
         self.hgLfSummaryAct.setStatusTip(self.tr(
@@ -194,8 +194,11 @@ class LargefilesProjectHelper(HgExtensionProjectHelper):
         
         @param direction direction of the conversion (string; one of
             'largefiles' or 'normal')
+        @exception ValueError raised to indicate a bad value for the
+            'direction' parameter.
         """
-        assert direction in ["largefiles", "normal"]
+        if direction not in ["largefiles", "normal"]:
+            raise ValueError("Bad value for 'direction' parameter.")
         
         self.vcs.getExtensionObject("largefiles").hgLfconvert(
             direction, self.project.getProjectFile())
@@ -218,8 +221,11 @@ class LargefilesProjectHelper(HgExtensionProjectHelper):
         Private slot to verify large files integrity.
         
         @param mode verify mode (string; one of 'large', 'lfa' or 'lfc')
+        @exception ValueError raised to indicate a bad value for the
+            'mode' parameter.
         """
-        assert mode in ['large', 'lfa', 'lfc']
+        if mode not in ['large', 'lfa', 'lfc']:
+            raise ValueError("Bad value for 'mode' parameter.")
         
         self.vcs.getExtensionObject("largefiles").hgLfVerify(
             self.project.getProjectPath(), mode)
