@@ -97,14 +97,6 @@ class ConfigurationWidget(QWidget):
         @keyparam expandedEntries list of entries to be shown expanded
             (list of strings)
         """
-        assert displayMode in (
-            ConfigurationWidget.DefaultMode,
-            ConfigurationWidget.HelpBrowserMode,
-            ConfigurationWidget.TrayStarterMode,
-            ConfigurationWidget.HexEditorMode,
-            ConfigurationWidget.WebBrowserMode,
-        )
-        
         super(ConfigurationWidget, self).__init__(parent)
         self.fromEric = fromEric
         self.displayMode = displayMode
@@ -230,9 +222,6 @@ class ConfigurationWidget(QWidget):
                 "debuggerGeneralPage":
                 [self.tr("General"), "preferences-debugger",
                  "DebuggerGeneralPage", "0debuggerPage", None],
-                "debuggerPython2Page":
-                [self.tr("Python2"), "preferences-pyDebugger",
-                 "DebuggerPython2Page", "0debuggerPage", None],
                 "debuggerPython3Page":
                 [self.tr("Python3"), "preferences-pyDebugger",
                  "DebuggerPython3Page", "0debuggerPage", None],
