@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -32,12 +32,29 @@ class GraphicsPage(ConfigurationPageBase, Ui_GraphicsPage):
         self.graphicsFont = Preferences.getGraphics("Font")
         self.graphicsFontSample.setFont(self.graphicsFont)
         
+        drawingMode = Preferences.getGraphics("DrawingMode")
+        if drawingMode == "black_white":
+            self.blackWhiteButton.setChecked(True)
+        elif drawingMode == "white_black":
+            self.whiteBlackButton.setChecked(True)
+        else:
+            self.automaticButton.setChecked(True)
+    
     def save(self):
         """
         Public slot to save the Printer configuration.
         """
         Preferences.setGraphics("Font", self.graphicsFont)
         
+        if self.blackWhiteButton.isChecked():
+            drawingMode = "black_white"
+        elif self.whiteBlackButton.isChecked():
+            drawingMode = "white_black"
+        else:
+            # default is automatic
+            drawingMode = "automatic"
+        Preferences.setGraphics("DrawingMode", drawingMode)
+    
     @pyqtSlot()
     def on_graphicsFontButton_clicked(self):
         """
