@@ -171,7 +171,7 @@ class WebBrowserPage(ConfigurationPageBase, Ui_WebBrowserPage):
         self.expireHistory.setCurrentIndex(idx)
         
         for language in range(2, QLocale.LastLanguage + 1):
-            countries = [l.country() for l in QLocale.matchingLocales(
+            countries = [loc.country() for loc in QLocale.matchingLocales(
                 language, QLocale.AnyScript, QLocale.AnyCountry)]
             if len(countries) > 0:
                 self.languageCombo.addItem(
