@@ -141,88 +141,42 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
             self.tr("Qt Assistant"), exe, version=version)
         
         # 2. do the PyQt programs
-        # 2.1 do the PyQt4 programs
-        # deprecated
-        # 2.1a. Translation Extractor PyQt4
-        self.__createProgramEntry(
-            self.tr("Translation Extractor (Python, PyQt4)"),
-            Utilities.generatePyQtToolPath("pylupdate4"),
-            '-version', 'pylupdate', -1)
-        # 2.1b. Forms Compiler PyQt4
-        self.__createProgramEntry(
-            self.tr("Forms Compiler (Python, PyQt4)"),
-            Utilities.generatePyQtToolPath("pyuic4", ["py3uic4"]),
-            '--version', 'Python User', 4)
-        # 2.1c. Resource Compiler PyQt4
-        self.__createProgramEntry(
-            self.tr("Resource Compiler (Python, PyQt4)"),
-            Utilities.generatePyQtToolPath("pyrcc4"),
-            '-version', 'Resource Compiler', -1)
-        
-        # 2.2 do the PyQt5 programs
-        # 2.2a. Translation Extractor PyQt5
+        # 2.1 do the PyQt5 programs
+        # 2.1a. Translation Extractor PyQt5
         self.__createProgramEntry(
             self.tr("Translation Extractor (Python, PyQt5)"),
             Utilities.generatePyQtToolPath("pylupdate5"),
             '-version', 'pylupdate', -1)
-        # 2.2b. Forms Compiler PyQt5
+        # 2.1b. Forms Compiler PyQt5
         self.__createProgramEntry(
             self.tr("Forms Compiler (Python, PyQt5)"),
             Utilities.generatePyQtToolPath("pyuic5", ["py3uic5"]),
             '--version', 'Python User', 4)
-        # 2.2c. Resource Compiler PyQt5
+        # 2.1c. Resource Compiler PyQt5
         self.__createProgramEntry(
             self.tr("Resource Compiler (Python, PyQt5)"),
             Utilities.generatePyQtToolPath("pyrcc5"),
             '-version', '', -1, versionRe='Resource Compiler|pyrcc5')
         
-        # 3.1 do the PySide programs
-        # 3.1a. Translation Extractor PySide
-        self.__createProgramEntry(
-            self.tr("Translation Extractor (Python, PySide)"),
-            Utilities.generatePySideToolPath("pyside-lupdate", "1"),
-            '-version', '', -1, versionRe='lupdate')
-        # 3.1b. Forms Compiler PySide
-        self.__createProgramEntry(
-            self.tr("Forms Compiler (Python, PySide)"),
-            Utilities.generatePySideToolPath("pyside-uic", "1"),
-            '--version', 'PySide User', 5, versionCleanup=(0, -1))
-        # 3.1c Resource Compiler PySide
-        self.__createProgramEntry(
-            self.tr("Resource Compiler (Python, PySide)"),
-            Utilities.generatePySideToolPath("pyside-rcc", "1"),
-            '-version', 'Resource Compiler', -1)
-        
-        # 3.2 do the PySide2 programs
-        # 3.2a. Translation Extractor PySide2
+        # 3. do the PySide programs
+        # 3.1 do the PySide2 programs
+        # 3.1a. Translation Extractor PySide2
         self.__createProgramEntry(
             self.tr("Translation Extractor (Python, PySide2)"),
-            Utilities.generatePySideToolPath("pyside2-lupdate", "2"),
+            Utilities.generatePySideToolPath("pyside2-lupdate"),
             '-version', '', -1, versionRe='lupdate')
-        # 3.2b. Forms Compiler PySide2
+        # 3.1b. Forms Compiler PySide2
         self.__createProgramEntry(
             self.tr("Forms Compiler (Python, PySide2)"),
-            Utilities.generatePySideToolPath("pyside2-uic", "2"),
+            Utilities.generatePySideToolPath("pyside2-uic"),
             '--version', '', -1, versionRe='uic')
-        # 3.2c Resource Compiler PySide2
+        # 3.1c Resource Compiler PySide2
         self.__createProgramEntry(
             self.tr("Resource Compiler (Python, PySide2)"),
-            Utilities.generatePySideToolPath("pyside2-rcc", "2"),
+            Utilities.generatePySideToolPath("pyside2-rcc"),
             '-version', '', -1, versionRe='rcc')
         
-        # 4. do the Ruby programs
-        # 4a. Forms Compiler for Qt4
-        self.__createProgramEntry(
-            self.tr("Forms Compiler (Ruby, Qt4)"),
-            Utilities.isWindowsPlatform() and "rbuic4.exe" or "rbuic4",
-            '-version', 'Qt', -1)
-        # 4b. Resource Compiler for Qt4
-        self.__createProgramEntry(
-            self.tr("Resource Compiler (Ruby, Qt4)"),
-            Utilities.isWindowsPlatform() and "rbrcc.exe" or "rbrcc",
-            '-version', 'Ruby Resource Compiler', -1)
-        
-        # 5. do the Conda program(s)
+        # 4. do the Conda program(s)
         exe = Preferences.getConda("CondaExecutable")
         if not exe:
             exe = "conda"
@@ -231,7 +185,7 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
         self.__createProgramEntry(
             self.tr("conda Manager"), exe, '--version', 'conda', -1)
         
-        # 6. do the pip program(s)
+        # 5. do the pip program(s)
         virtualenvManager = e5App().getObject("VirtualEnvManager")
         for venvName in virtualenvManager.getVirtualenvNames():
             interpreter = virtualenvManager.getVirtualenvInterpreter(venvName)
@@ -239,8 +193,8 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
                 self.tr("PyPI Package Management"), interpreter, '--version',
                 'pip', 1, exeModule=["-m", "pip"])
         
-        # 7. do the CORBA and Protobuf programs
-        # 7a. omniORB
+        # 6. do the CORBA and Protobuf programs
+        # 6a. omniORB
         exe = Preferences.getCorba("omniidl")
         if not exe:
             exe = "omniidl"
@@ -248,7 +202,7 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
                 exe += ".exe"
         self.__createProgramEntry(
             self.tr("CORBA IDL Compiler"), exe, '-V', 'omniidl', -1)
-        # 7b. protobuf
+        # 6b. protobuf
         exe = Preferences.getProtobuf("protoc")
         if not exe:
             exe = "protoc"
@@ -256,7 +210,7 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
                 exe += ".exe"
         self.__createProgramEntry(
             self.tr("Protobuf Compiler"), exe, '--version', 'libprotoc', -1)
-        # 7c. grpc
+        # 6c. grpc
         exe = Preferences.getProtobuf("grpcPython")
         if not exe:
             exe = sys.executable
@@ -264,7 +218,7 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
             self.tr("gRPC Compiler"), exe, '--version', 'libprotoc', -1,
             exeModule=['-m', 'grpc_tools.protoc'])
         
-        # 8. do the spell checking entry
+        # 7. do the spell checking entry
         try:
             import enchant
             try:
@@ -281,7 +235,7 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
         self.__createEntry(
             self.tr("Spell Checker - PyEnchant"), text, version)
         
-        # 9. do the pygments entry
+        # 8. do the pygments entry
         try:
             import pygments
             try:
@@ -298,7 +252,7 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
         self.__createEntry(
             self.tr("Source Highlighter - Pygments"), text, version)
         
-        # 10. do the MicroPython related entries
+        # 9. do the MicroPython related entries
         exe = Preferences.getMicroPython("MpyCrossCompiler")
         if not exe:
             exe = "mpy-cross"
