@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -44,7 +44,7 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
         self.dirPicker.setMode(E5PathPickerModes.DirectoryMode)
         self.mainscriptPicker.setMode(E5PathPickerModes.OpenFileMode)
         
-        self.makeButton.setIcon(UI.PixmapCache.getIcon("makefile.png"))
+        self.makeButton.setIcon(UI.PixmapCache.getIcon("makefile"))
         
         self.project = project
         self.newProject = new
