@@ -30,7 +30,6 @@ from .Ui_UnittestDialog import Ui_UnittestDialog
 
 import UI.PixmapCache
 
-import Utilities
 import Preferences
 
 
@@ -288,17 +287,13 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         Private slot called before the test suite selection dialog is shown.
         """
         if self.__dbs:
-            py2Extensions = ' '.join(
-                ["*{0}".format(ext)
-                 for ext in self.__dbs.getExtensions('Python2')]
-            )
             py3Extensions = ' '.join(
                 ["*{0}".format(ext)
                  for ext in self.__dbs.getExtensions('Python3')]
             )
             fileFilter = self.tr(
-                "Python3 Files ({1});;Python2 Files ({0});;All Files (*)"
-            ).format(py2Extensions, py3Extensions)
+                "Python3 Files ({0});;All Files (*)"
+            ).format(py3Extensions)
         else:
             fileFilter = self.tr("Python Files (*.py);;All Files (*)")
         self.testsuitePicker.setFilters(fileFilter)
@@ -407,10 +402,7 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
                     return
                 
                 workdir = ""
-                clientType = self.__venvManager.getVirtualenvVariant(venvName)
-                if not clientType:
-                    # assume Python 3
-                    clientType = "Python3"
+                clientType = "Python3"
                 sysPath = []
             self.__dbs.remoteUTDiscover(clientType, self.__forProject,
                                         venvName, sysPath, workdir,
@@ -756,34 +748,16 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
                     
                     coverageFile = os.path.join(discoveryStart, "unittest")
                     workdir = ""
-                    clientType = self.__venvManager.getVirtualenvVariant(
-                        venvName)
-                    if not clientType:
-                        # assume Python 3
-                        clientType = "Python3"
+                    clientType = "Python3"
                 elif testFileName:
                     mainScript = os.path.abspath(testFileName)
-                    flags = Utilities.extractFlagsFromFile(mainScript)
                     workdir = os.path.dirname(mainScript)
-                    if (
-                        mainScript.endswith(tuple(
-                            Preferences.getPython("PythonExtensions"))) or
-                        ("FileType" in flags and
-                         flags["FileType"] in ["Python", "Python2"])
-                    ):
-                        clientType = "Python2"
-                    else:
-                        # if it is not Python2 it must be Python3!
-                        clientType = "Python3"
+                    clientType = "Python3"
                     coverageFile = os.path.splitext(mainScript)[0]
                 else:
                     coverageFile = os.path.abspath("unittest")
                     workdir = ""
-                    clientType = self.__venvManager.getVirtualenvVariant(
-                        venvName)
-                    if not clientType:
-                        # assume Python 3
-                        clientType = "Python3"
+                    clientType = "Python3"
                 sysPath = []
             if failedOnly and self.__failedTests:
                 failed = self.__failedTests[:]
@@ -1239,7 +1213,7 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         for editor in self.__editors:
             try:
                 editor.close()
-            except Exception:
+            except Exception:           # secok
                 # ignore all exceptions
                 pass
 
