@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -1426,7 +1426,10 @@ class QsciScintillaCompat(QsciScintilla):
         @param event event object (QFocusEvent)
         """
         if self.isListActive():
-            if event.reason() == Qt.ActiveWindowFocusReason:
+            if event.reason() in [
+                Qt.ActiveWindowFocusReason,
+                Qt.OtherFocusReason
+            ]:
                 aw = QApplication.activeWindow()
                 if aw is None or aw.parent() is not self:
                     self.cancelList()
@@ -1434,7 +1437,10 @@ class QsciScintillaCompat(QsciScintilla):
                 self.cancelList()
         
         if self.isCallTipActive():
-            if event.reason() == Qt.ActiveWindowFocusReason:
+            if event.reason() in [
+                Qt.ActiveWindowFocusReason,
+                Qt.OtherFocusReason
+            ]:
                 aw = QApplication.activeWindow()
                 if aw is None or aw.parent() is not self:
                     self.SendScintilla(QsciScintilla.SCI_CALLTIPCANCEL)
@@ -1569,8 +1575,8 @@ class QsciScintillaCompat(QsciScintilla):
                 height += (
                     userListWidget.horizontalScrollBar().sizeHint().height()
                 )
-                # List box doesn't honor limited size to show scroll bars, e.g.
-                # Python 2 on Win 10. So just force it.
+                # List box doesn't honor limited size to show scroll bars.
+                # So just force it.
                 userListWidget.setHorizontalScrollBarPolicy(
                     Qt.ScrollBarAlwaysOn)
             
