@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -97,72 +97,72 @@ class TrayStarter(QSystemTrayIcon):
         self.__menu.addSeparator()
         
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("uiPreviewer.png"),
+            UI.PixmapCache.getIcon("uiPreviewer"),
             self.tr("UI Previewer"), self.__startUIPreviewer)
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("trPreviewer.png"),
+            UI.PixmapCache.getIcon("trPreviewer"),
             self.tr("Translations Previewer"), self.__startTRPreviewer)
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("unittest.png"),
+            UI.PixmapCache.getIcon("unittest"),
             self.tr("Unittest"), self.__startUnittest)
         self.__menu.addSeparator()
         
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("diffFiles.png"),
+            UI.PixmapCache.getIcon("diffFiles"),
             self.tr("Compare Files"), self.__startDiff)
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("compareFiles.png"),
+            UI.PixmapCache.getIcon("compareFiles"),
             self.tr("Compare Files side by side"), self.__startCompare)
         self.__menu.addSeparator()
         
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("sqlBrowser.png"),
+            UI.PixmapCache.getIcon("sqlBrowser"),
             self.tr("SQL Browser"), self.__startSqlBrowser)
         self.__menu.addSeparator()
         
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("ericSnap.png"),
+            UI.PixmapCache.getIcon("ericSnap"),
             self.tr("Snapshot"), self.__startSnapshot)
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("iconEditor.png"),
+            UI.PixmapCache.getIcon("iconEditor"),
             self.tr("Icon Editor"), self.__startIconEditor)
         self.__menu.addSeparator()
         
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("pluginInstall.png"),
+            UI.PixmapCache.getIcon("pluginInstall"),
             self.tr("Install Plugin"), self.__startPluginInstall)
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("pluginUninstall.png"),
+            UI.PixmapCache.getIcon("pluginUninstall"),
             self.tr("Uninstall Plugin"), self.__startPluginUninstall)
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("pluginRepository.png"),
+            UI.PixmapCache.getIcon("pluginRepository"),
             self.tr("Plugin Repository"), self.__startPluginRepository)
         self.__menu.addSeparator()
         
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("configure.png"),
+            UI.PixmapCache.getIcon("configure"),
             self.tr('Preferences'), self.__startPreferences)
         self.__menu.addSeparator()
         
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("erict.png"),
+            UI.PixmapCache.getIcon("erict"),
             self.tr("eric6 IDE"), self.__startEric)
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("editor.png"),
+            UI.PixmapCache.getIcon("editor"),
             self.tr("eric6 Mini Editor"), self.__startMiniEditor)
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("hexEditor.png"),
+            UI.PixmapCache.getIcon("hexEditor"),
             self.tr("eric6 Hex Editor"), self.__startHexEditor)
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("ericWeb.png"),
+            UI.PixmapCache.getIcon("ericWeb"),
             self.tr("eric6 Web Browser"), self.__startHelpViewer)
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("shell.png"),
+            UI.PixmapCache.getIcon("shell"),
             self.tr("eric6 Shell Window"), self.__startShell)
         self.__menu.addSeparator()
         
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("configure.png"),
+            UI.PixmapCache.getIcon("configure"),
             self.tr('Configure Tray Starter'), self.__showPreferences)
         self.__menu.addSeparator()
         
@@ -177,7 +177,7 @@ class TrayStarter(QSystemTrayIcon):
         self.__menu.addSeparator()
         
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("exit.png"),
+            UI.PixmapCache.getIcon("exit"),
             self.tr('Quit'), qApp.quit)
     
     def __loadRecentProjects(self):
