@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -54,7 +54,7 @@ class UIPreviewer(E5MainWindow):
         self.resize(QSize(600, 480).expandedTo(self.minimumSizeHint()))
         self.statusBar()
         
-        self.setWindowIcon(UI.PixmapCache.getIcon("eric.png"))
+        self.setWindowIcon(UI.PixmapCache.getIcon("eric"))
         self.setWindowTitle(self.tr("UI Previewer"))
 
         self.cw = QWidget(self)
@@ -128,7 +128,7 @@ class UIPreviewer(E5MainWindow):
         Private method to define the user interface actions.
         """
         self.openAct = QAction(
-            UI.PixmapCache.getIcon("openUI.png"),
+            UI.PixmapCache.getIcon("openUI"),
             self.tr('&Open File'), self)
         self.openAct.setShortcut(
             QKeySequence(self.tr("Ctrl+O", "File|Open")))
@@ -140,7 +140,7 @@ class UIPreviewer(E5MainWindow):
         self.openAct.triggered.connect(self.__openFile)
         
         self.printAct = QAction(
-            UI.PixmapCache.getIcon("print.png"),
+            UI.PixmapCache.getIcon("print"),
             self.tr('&Print'), self)
         self.printAct.setShortcut(
             QKeySequence(self.tr("Ctrl+P", "File|Print")))
@@ -152,7 +152,7 @@ class UIPreviewer(E5MainWindow):
         self.printAct.triggered.connect(self.__printImage)
         
         self.printPreviewAct = QAction(
-            UI.PixmapCache.getIcon("printPreview.png"),
+            UI.PixmapCache.getIcon("printPreview"),
             self.tr('Print Preview'), self)
         self.printPreviewAct.setStatusTip(self.tr(
             'Print preview a screen capture'))
@@ -163,7 +163,7 @@ class UIPreviewer(E5MainWindow):
         self.printPreviewAct.triggered.connect(self.__printPreviewImage)
         
         self.imageAct = QAction(
-            UI.PixmapCache.getIcon("screenCapture.png"),
+            UI.PixmapCache.getIcon("screenCapture"),
             self.tr('&Screen Capture'), self)
         self.imageAct.setShortcut(
             QKeySequence(self.tr("Ctrl+S", "File|Screen Capture")))
@@ -176,7 +176,7 @@ class UIPreviewer(E5MainWindow):
         self.imageAct.triggered.connect(self.__saveImage)
         
         self.exitAct = QAction(
-            UI.PixmapCache.getIcon("exit.png"), self.tr('&Quit'), self)
+            UI.PixmapCache.getIcon("exit"), self.tr('&Quit'), self)
         self.exitAct.setShortcut(
             QKeySequence(self.tr("Ctrl+Q", "File|Quit")))
         self.exitAct.setStatusTip(self.tr('Quit the application'))
@@ -187,7 +187,7 @@ class UIPreviewer(E5MainWindow):
         self.exitAct.triggered.connect(qApp.closeAllWindows)
         
         self.copyAct = QAction(
-            UI.PixmapCache.getIcon("editCopy.png"), self.tr('&Copy'), self)
+            UI.PixmapCache.getIcon("editCopy"), self.tr('&Copy'), self)
         self.copyAct.setShortcut(
             QKeySequence(self.tr("Ctrl+C", "Edit|Copy")))
         self.copyAct.setStatusTip(
@@ -199,7 +199,7 @@ class UIPreviewer(E5MainWindow):
         self.copyAct.triggered.connect(self.__copyImageToClipboard)
         
         self.whatsThisAct = QAction(
-            UI.PixmapCache.getIcon("whatsThis.png"),
+            UI.PixmapCache.getIcon("whatsThis"),
             self.tr('&What\'s This?'), self)
         self.whatsThisAct.setShortcut(QKeySequence(self.tr("Shift+F1")))
         self.whatsThisAct.setStatusTip(self.tr('Context sensitive help'))
@@ -345,7 +345,7 @@ class UIPreviewer(E5MainWindow):
         # load the file
         try:
             self.mainWidget = uic.loadUi(fn)
-        except Exception:
+        except Exception:       # secok
             pass
         
         if self.mainWidget:
