@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -111,10 +111,10 @@ class CompareDialog(QWidget, Ui_CompareDialog):
         self.diffButton.setEnabled(False)
         self.diffButton.setDefault(True)
         
-        self.firstButton.setIcon(UI.PixmapCache.getIcon("2uparrow.png"))
-        self.upButton.setIcon(UI.PixmapCache.getIcon("1uparrow.png"))
-        self.downButton.setIcon(UI.PixmapCache.getIcon("1downarrow.png"))
-        self.lastButton.setIcon(UI.PixmapCache.getIcon("2downarrow.png"))
+        self.firstButton.setIcon(UI.PixmapCache.getIcon("2uparrow"))
+        self.upButton.setIcon(UI.PixmapCache.getIcon("1uparrow"))
+        self.downButton.setIcon(UI.PixmapCache.getIcon("1downarrow"))
+        self.lastButton.setIcon(UI.PixmapCache.getIcon("2downarrow"))
         
         self.totalLabel.setText(self.tr('Total: {0}').format(0))
         self.changedLabel.setText(self.tr('Changed: {0}').format(0))
