@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -580,10 +580,12 @@ class PreviewProcessingThread(QThread):
                 """<p>Alternatively you may disable Sphinx usage"""
                 """ on the Editor, Filehandling configuration page.</p>""")
         
-        tempDir = tempfile.mkdtemp(prefix='eric-rest-')
+        srcTempDir = tempfile.mkdtemp(prefix="eric-rest-src-")
+        outTempDir = tempfile.mkdtemp(prefix="eric-rest-out-")
+        doctreeTempDir = tempfile.mkdtemp(prefix="eric-rest-doctree-")
         try:
             filename = 'sphinx_preview'
-            basePath = os.path.join(tempDir, filename)
+            basePath = os.path.join(srcTempDir, filename)
             fh = open(basePath + '.rst', 'w', encoding='utf-8')
             fh.write(text)
             fh.close()
@@ -595,17 +597,20 @@ class PreviewProcessingThread(QThread):
                          'html_use_modindex': False,
                          'html_use_smartypants': True,
                          'master_doc': filename}
-            app = Sphinx(srcdir=tempDir, confdir=None, outdir=tempDir,
-                         doctreedir=tempDir, buildername='html',
+            app = Sphinx(srcdir=srcTempDir, confdir=None, outdir=outTempDir,
+                         doctreedir=doctreeTempDir, buildername='html',
                          confoverrides=overrides, status=None,
                          warning=io.StringIO())
             app.build(force_all=True, filenames=None)
 
+            basePath = os.path.join(outTempDir, filename)
             fh = open(basePath + '.html', 'r', encoding='utf-8')
             html = fh.read()
             fh.close()
         finally:
-            shutil.rmtree(tempDir)
+            shutil.rmtree(srcTempDir)
+            shutil.rmtree(outTempDir)
+            shutil.rmtree(doctreeTempDir)
         
         return html
     
@@ -743,12 +748,37 @@ class PreviewProcessingThread(QThread):
                 " src='https://unpkg.com/mermaid@8/dist/mermaid.min.js'>\n"
                 "</script>\n"
             )
+            if e5App().usesDarkPalette():
+                mermaid_initialize = (
+                    "<script>mermaid.initialize({"
+                    "theme: 'dark', "
+                    "startOnLoad:true"
+                    "});</script>"
+                )
+            else:
+                mermaid_initialize = (
+                    "<script>mermaid.initialize({"
+                    "theme: 'default', "
+                    "startOnLoad:true"
+                    "});</script>"
+                )
         else:
             mermaid = ""
+            mermaid_initialize = ""
         
         htmlFormat = Preferences.getEditor("PreviewMarkdownHTMLFormat").lower()
         body = markdown.markdown(text, extensions=extensions,
                                  output_format=htmlFormat.lower())
+        if e5App().usesDarkPalette():
+            style = (
+                PreviewerHTMLStyles.css_markdown_dark +
+                PreviewerHTMLStyles.css_pygments_dark
+            )
+        else:
+            style = (
+                PreviewerHTMLStyles.css_markdown_light +
+                PreviewerHTMLStyles.css_pygments_light
+            )
         
         if htmlFormat == "xhtml1":
             head = (
@@ -777,12 +807,8 @@ class PreviewProcessingThread(QThread):
             '''</style>\n'''
             '''</head>\n'''
             '''<body>\n'''
-        ).format(
-            mathjax, mermaid,
-            PreviewerHTMLStyles.css_markdown +
-            PreviewerHTMLStyles.css_pygments
-        )
+        ).format(mathjax, mermaid, style)
         
         foot = '''\n</body>\n</html>\n'''
         
-        return head + body + foot
+        return head + body + mermaid_initialize + foot
