@@ -240,6 +240,8 @@ def readmodule_ex(module, path=None):
         # can't do anything with this module
         _modules[module] = dictionary
         return dictionary
+    # convert eol markers the Python style
+    src = src.replace("\r\n", "\n").replace("\r", "\n")
 
     lineno, last_lineno_pos = 1, 0
     lastGlobalEntry = None
