@@ -497,6 +497,8 @@ class Module(object):
         
         @param src the source text to be scanned (string)
         """
+        # convert eol markers the Python style
+        src = src.replace("\r\n", "\n").replace("\r", "\n")
         if self.type in [PY_SOURCE, PTL_SOURCE]:
             self.__py_scan(src)
         elif self.type == RB_SOURCE:
