@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -67,7 +67,7 @@ class VcsProjectHelper(QObject):
         self.vcsNewAct = E5Action(
             QCoreApplication.translate(
                 "VcsProjectHelper", 'New from repository'),
-            UI.PixmapCache.getIcon("vcsCheckout.png"),
+            UI.PixmapCache.getIcon("vcsCheckout"),
             QCoreApplication.translate(
                 "VcsProjectHelper", '&New from repository...'),
             0, 0, self, 'vcs_new')
@@ -87,7 +87,7 @@ class VcsProjectHelper(QObject):
         self.vcsExportAct = E5Action(
             QCoreApplication.translate(
                 "VcsProjectHelper", 'Export from repository'),
-            UI.PixmapCache.getIcon("vcsExport.png"),
+            UI.PixmapCache.getIcon("vcsExport"),
             QCoreApplication.translate(
                 "VcsProjectHelper", '&Export from repository...'),
             0, 0, self, 'vcs_export')
@@ -106,7 +106,7 @@ class VcsProjectHelper(QObject):
         self.vcsAddAct = E5Action(
             QCoreApplication.translate(
                 "VcsProjectHelper", 'Add to repository'),
-            UI.PixmapCache.getIcon("vcsCommit.png"),
+            UI.PixmapCache.getIcon("vcsCommit"),
             QCoreApplication.translate(
                 "VcsProjectHelper", '&Add to repository...'),
             0, 0, self, 'vcs_add')
