@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2016 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2016 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -213,13 +213,13 @@ class AutoScroller(QObject):
         
         if vertical and horizontal:
             self.__indicator.setPixmap(
-                UI.PixmapCache.getPixmap("scrollAll.png"))
+                UI.PixmapCache.getPixmap("scrollAll"))
         elif vertical:
             self.__indicator.setPixmap(
-                UI.PixmapCache.getPixmap("scrollVertical.png"))
+                UI.PixmapCache.getPixmap("scrollVertical"))
         else:
             self.__indicator.setPixmap(
-                UI.PixmapCache.getPixmap("scrollHorizontal.png"))
+                UI.PixmapCache.getPixmap("scrollHorizontal"))
         
         self.__view = view
         p = QPoint(
