@@ -65,9 +65,9 @@ class DownloadItem(QWidget, Ui_DownloadItem):
         
         self.progressBar.setMaximum(0)
         
-        self.pauseButton.setIcon(UI.PixmapCache.getIcon("pause.png"))
-        self.stopButton.setIcon(UI.PixmapCache.getIcon("stopLoading.png"))
-        self.openButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        self.pauseButton.setIcon(UI.PixmapCache.getIcon("pause"))
+        self.stopButton.setIcon(UI.PixmapCache.getIcon("stopLoading"))
+        self.openButton.setIcon(UI.PixmapCache.getIcon("open"))
         self.openButton.setEnabled(False)
         self.openButton.setVisible(False)
         if not hasattr(QWebEngineDownloadItem, "pause"):
