@@ -375,14 +375,14 @@ class HistoryMenu(E5ModelMenu):
                 self.newPrivateWindow)
         self.addMenu(self.__mostVisitedMenu)
         act = self.addMenu(self.__closedTabsMenu)
-        act.setIcon(UI.PixmapCache.getIcon("trash.png"))
+        act.setIcon(UI.PixmapCache.getIcon("trash"))
         act.setEnabled(self.__tabWidget.canRestoreClosedTab())
         self.addSeparator()
         
-        act = self.addAction(UI.PixmapCache.getIcon("history.png"),
+        act = self.addAction(UI.PixmapCache.getIcon("history"),
                              self.tr("Show All History..."))
         act.triggered.connect(self.showHistoryDialog)
-        act = self.addAction(UI.PixmapCache.getIcon("historyClear.png"),
+        act = self.addAction(UI.PixmapCache.getIcon("historyClear"),
                              self.tr("Clear History..."))
         act.triggered.connect(self.__clearHistoryDialog)
     
@@ -426,7 +426,10 @@ class HistoryMenu(E5ModelMenu):
         Private slot to populate the closed tabs menu.
         """
         fm = self.__closedTabsMenu.fontMetrics()
-        maxWidth = fm.width('m') * 40
+        try:
+            maxWidth = fm.horizontalAdvance('m') * 40
+        except AttributeError:
+            maxWidth = fm.width('m') * 40
         
         import WebBrowser.WebBrowserWindow
         self.__closedTabsMenu.clear()
