@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -71,7 +71,7 @@ class HistoryTreeModel(QAbstractProxyModel):
         
         elif role == Qt.DecorationRole:
             if index.column() == 0 and not index.parent().isValid():
-                return UI.PixmapCache.getIcon("history.png")
+                return UI.PixmapCache.getIcon("history")
         
         elif role == HistoryModel.DateRole:
             if index.column() == 0 and index.internalId() == 0:
