@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2017 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2017 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -58,7 +58,7 @@ class NavigationBar(QWidget):
         self.__backButton.setFocusPolicy(Qt.NoFocus)
         self.__backButton.setAutoRaise(True)
         self.__backButton.setIcon(
-            UI.PixmapCache.getIcon("back.png"))
+            UI.PixmapCache.getIcon("back"))
         self.__backButton.setEnabled(False)
         
         self.__forwardButton = E5ToolButton(self)
@@ -68,7 +68,7 @@ class NavigationBar(QWidget):
         self.__forwardButton.setFocusPolicy(Qt.NoFocus)
         self.__forwardButton.setAutoRaise(True)
         self.__forwardButton.setIcon(
-            UI.PixmapCache.getIcon("forward.png"))
+            UI.PixmapCache.getIcon("forward"))
         self.__forwardButton.setEnabled(False)
         
         self.__backNextLayout = QHBoxLayout()
@@ -86,13 +86,13 @@ class NavigationBar(QWidget):
         self.__homeButton.setFocusPolicy(Qt.NoFocus)
         self.__homeButton.setAutoRaise(True)
         self.__homeButton.setIcon(
-            UI.PixmapCache.getIcon("home.png"))
+            UI.PixmapCache.getIcon("home"))
         
         self.__exitFullScreenButton = E5ToolButton(self)
         self.__exitFullScreenButton.setObjectName(
             "navigation_exitfullscreen_button")
         self.__exitFullScreenButton.setIcon(
-            UI.PixmapCache.getIcon("windowRestore.png"))
+            UI.PixmapCache.getIcon("windowRestore"))
         self.__exitFullScreenButton.setToolTip(self.tr("Exit Fullscreen"))
         self.__exitFullScreenButton.setToolButtonStyle(Qt.ToolButtonIconOnly)
         self.__exitFullScreenButton.setFocusPolicy(Qt.NoFocus)
@@ -105,7 +105,7 @@ class NavigationBar(QWidget):
         self.__superMenuButton = E5ToolButton(self)
         self.__superMenuButton.setObjectName(
             "navigation_supermenu_button")
-        self.__superMenuButton.setIcon(UI.PixmapCache.getIcon("superMenu.png"))
+        self.__superMenuButton.setIcon(UI.PixmapCache.getIcon("superMenu"))
         self.__superMenuButton.setToolTip(self.tr("Main Menu"))
         self.__superMenuButton.setPopupMode(QToolButton.InstantPopup)
         self.__superMenuButton.setToolButtonStyle(Qt.ToolButtonIconOnly)
@@ -233,7 +233,7 @@ class NavigationBar(QWidget):
         for index in range(len(backItems) - 1, -1, -1):
             item = backItems[index]
             act = QAction(self)
-            act.setData(-1 * (index + 1))
+            act.setData(item)
             icon = WebBrowserWindow.icon(item.url())
             act.setIcon(icon)
             act.setText(item.title())
@@ -260,7 +260,7 @@ class NavigationBar(QWidget):
         for index in range(len(forwardItems)):
             item = forwardItems[index]
             act = QAction(self)
-            act.setData(index + 1)
+            act.setData(item)
             icon = WebBrowserWindow.icon(item.url())
             act.setIcon(icon)
             act.setText(item.title())
@@ -281,18 +281,10 @@ class NavigationBar(QWidget):
         @param act reference to the action selected in the navigation menu
             (QAction)
         """
-        offset = act.data()
-        if offset is not None:
+        historyItem = act.data()
+        if historyItem is not None:
             history = self.__mw.currentBrowser().history()
-            historyCount = history.count()
-            if offset < 0:
-                # go back
-                history.goToItem(
-                    history.backItems(historyCount)[-1 * offset - 1])
-            else:
-                # go forward
-                history.goToItem(
-                    history.forwardItems(historyCount)[offset - 1])
+            history.goToItem(historyItem)
     
     def __goBack(self):
         """
