@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2017 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2017 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -284,12 +284,14 @@ class SafeBrowsingCache(QObject):
             VALUES
                 (?, ?, ?, ?, ?, current_timestamp)
         """
-        updateQueryStr = """
+        updateQueryStr = (
+            """
             UPDATE full_hash SET
-                expires_at=datetime(current_timestamp, '+{0} SECONDS')
+            expires_at=datetime(current_timestamp, '+{0} SECONDS')
             WHERE value=? AND threat_type=? AND platform_type=? AND
             threat_entry_type=?
-        """.format(int(cacheDuration))
+            """.format(int(cacheDuration))
+        )
         
         db = QSqlDatabase.database(self.__connectionName)
         if db.isOpen():
@@ -352,10 +354,12 @@ class SafeBrowsingCache(QObject):
         @param keepExpiredFor time period in seconds of entries to be expired
         @type int or float
         """
-        queryStr = """
+        queryStr = (
+            """
             DELETE FROM full_hash
-                WHERE expires_at=datetime(current_timestamp, '{0} SECONDS')
-        """.format(int(keepExpiredFor))
+            WHERE expires_at=datetime(current_timestamp, '{0} SECONDS')
+            """.format(int(keepExpiredFor))
+        )
         
         db = QSqlDatabase.database(self.__connectionName)
         if db.isOpen():
@@ -381,12 +385,14 @@ class SafeBrowsingCache(QObject):
             in the cache
         @type int or float
         """
-        queryStr = """
+        queryStr = (
+            """
             UPDATE hash_prefix
             SET negative_expires_at=datetime(current_timestamp, '+{0} SECONDS')
             WHERE value=? AND threat_type=? AND platform_type=? AND
             threat_entry_type=?
-        """.format(int(negativeCacheDuration))
+            """.format(int(negativeCacheDuration))
+        )
         
         db = QSqlDatabase.database(self.__connectionName)
         if db.isOpen():
@@ -657,11 +663,13 @@ class SafeBrowsingCache(QObject):
         @param indexes list of indexes of prefixes to be removed
         @type list of int
         """
-        queryStr = """
+        queryStr = (
+            """
             DELETE FROM hash_prefix
             WHERE threat_type=? AND platform_type=? AND
             threat_entry_type=? AND value IN ({0})
-        """
+            """
+        )
         batchSize = 40
         
         prefixesToRemove = self.getHashPrefixValuesToRemove(
@@ -692,3 +700,6 @@ class SafeBrowsingCache(QObject):
                             QEventLoop.AllEvents, self.maxProcessEventsTime)
                 finally:
                     db.commit()
+
+#
+# eflag: noqa = S608
