@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2019 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -59,15 +59,22 @@ class SiteInfoWidget(QMenu):
         secureLabel.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Preferred)
         layout.addWidget(secureLabel, rows, 1)
         if url.scheme() in ["https"]:
-            secureLabel.setText(
-                self.tr("Your connection to this site is <b>secure</b>."))
-            secureIcon.setPixmap(
-                UI.PixmapCache.getPixmap("securityHigh.png"))
+            if WebBrowserWindow.networkManager().isInsecureHost(url.host()):
+                secureLabel.setText(
+                    self.tr("Your connection to this site "
+                            "<b>may not be secure</b>."))
+                secureIcon.setPixmap(
+                    UI.PixmapCache.getPixmap("securityMedium"))
+            else:
+                secureLabel.setText(
+                    self.tr("Your connection to this site is <b>secure</b>."))
+                secureIcon.setPixmap(
+                    UI.PixmapCache.getPixmap("securityHigh"))
         else:
             secureLabel.setText(
                 self.tr("Your connection to this site is <b>not secure</b>."))
             secureIcon.setPixmap(
-                UI.PixmapCache.getPixmap("securityLow.png"))
+                UI.PixmapCache.getPixmap("securityLow"))
         rows += 1
         
         visits = WebBrowserWindow.historyManager().siteVisitsCount(
@@ -83,16 +90,16 @@ class SiteInfoWidget(QMenu):
                 self.tr("This is your <b>{0}.</b> visit of this site.")
                 .format(visits))
             historyIcon.setPixmap(
-                UI.PixmapCache.getPixmap("flagGreen.png"))
+                UI.PixmapCache.getPixmap("flagGreen"))
         elif visits == 0:
             historyLabel.setText(
                 self.tr("You have <b>never</b> visited this site before.")
                 .format(visits))
             historyIcon.setPixmap(
-                UI.PixmapCache.getPixmap("flagBlack.png"))
+                UI.PixmapCache.getPixmap("flagBlack"))
         else:
             historyIcon.setPixmap(
-                UI.PixmapCache.getPixmap("flagYellow.png"))
+                UI.PixmapCache.getPixmap("flagYellow"))
             if visits == 1:
                 visitStr = self.tr("first")
             elif visits == 2:
