@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2016 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2016 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -289,7 +289,7 @@ class TabManagerWidget(QWidget):
                 if not browser.isLoading():
                     tabItem.setIcon(0, browser.icon())
                 else:
-                    tabItem.setIcon(0, UI.PixmapCache.getIcon("loading.png"))
+                    tabItem.setIcon(0, UI.PixmapCache.getIcon("loading"))
                 tabItem.setText(0, browser.title())
                 tabItem.setToolTip(0, browser.title())
                 
@@ -333,7 +333,7 @@ class TabManagerWidget(QWidget):
                 if not browser.isLoading():
                     tabItem.setIcon(0, browser.icon())
                 else:
-                    tabItem.setIcon(0, UI.PixmapCache.getIcon("loading.png"))
+                    tabItem.setIcon(0, UI.PixmapCache.getIcon("loading"))
                 tabItem.setText(0, browser.title())
                 tabItem.setToolTip(0, browser.title())
                 
@@ -527,12 +527,12 @@ class TabManagerWidget(QWidget):
         
         if self.__isBrowserSelected():
             act = menu.addAction(
-                UI.PixmapCache.getIcon("bookmark22.png"),
+                UI.PixmapCache.getIcon("bookmark22"),
                 self.tr("&Bookmark checked tabs"))
             act.setObjectName("bookmarkSelection")
             act.triggered.connect(lambda: self.__processActions(act))
             act = menu.addAction(
-                UI.PixmapCache.getIcon("tabClose.png"),
+                UI.PixmapCache.getIcon("tabClose"),
                 self.tr("&Close checked tabs"))
             act.setObjectName("closeSelection")
             act.triggered.connect(lambda: self.__processActions(act))
@@ -564,7 +564,7 @@ class TabManagerWidget(QWidget):
         """
         icon = E5ClickableLabel()
         icon.setPixmap(
-            UI.PixmapCache.getPixmap("tabManager.png").scaled(16, 16))
+            UI.PixmapCache.getPixmap("tabManager").scaled(16, 16))
         icon.setToolTip(self.tr("Show Tab Manager"))
         icon.clicked.connect(lambda: self.raiseTabManager(icon))
         
