@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2016 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2016 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -19,7 +19,7 @@ class WebIconLoader(QObject):
     """
     Class implementing a loader for web site icons.
     
-    @signal iconLoaded(icon) emitted when the con has been loaded
+    @signal iconLoaded(icon) emitted when the icon has been loaded
     """
     iconLoaded = pyqtSignal(QIcon)
     
@@ -50,5 +50,7 @@ class WebIconLoader(QObject):
         icon = QIcon(QPixmap.fromImage(QImage.fromData(data)))
         self.iconLoaded.emit(icon)
         
+        # TODO: extract SSL data as a by-product
+        
         self.__reply.deleteLater()
         self.__reply = None
