@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2016 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2016 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -80,7 +80,7 @@ class WebIconProvider(QObject):
     
     def load(self):
         """
-        Public method to load the bookmarks.
+        Public method to load the web site icons.
         """
         if self.__loaded:
             return
@@ -105,7 +105,7 @@ class WebIconProvider(QObject):
     
     def save(self):
         """
-        Public method to save the zoom values.
+        Public method to save the web site icons.
         """
         if not self.__loaded:
             return
@@ -161,7 +161,7 @@ class WebIconProvider(QObject):
         @rtype str
         """
         return url.toString(QUrl.PrettyDecoded | QUrl.RemoveUserInfo |
-                            QUrl.RemoveFragment)
+                            QUrl.RemoveFragment | QUrl.RemovePath)
     
     def iconForUrl(self, url):
         """
@@ -174,36 +174,42 @@ class WebIconProvider(QObject):
         """
         scheme = url.scheme()
         if scheme in ["eric", "about"]:
-            return UI.PixmapCache.getIcon("ericWeb.png")
+            return UI.PixmapCache.getIcon("ericWeb")
         elif scheme == "qthelp":
-            return UI.PixmapCache.getIcon("qthelp.png")
+            return UI.PixmapCache.getIcon("qthelp")
         elif scheme == "file":
-            return UI.PixmapCache.getIcon("fileMisc.png")
+            return UI.PixmapCache.getIcon("fileMisc")
         elif scheme == "abp":
-            return UI.PixmapCache.getIcon("adBlockPlus.png")
+            return UI.PixmapCache.getIcon("adBlockPlus")
         elif scheme == "ftp":
-            return UI.PixmapCache.getIcon("network-server.png")
+            return UI.PixmapCache.getIcon("network-server")
         
         self.load()
         
         urlStr = self.__urlToString(url)
-        for iconUrlStr in self.__iconsDB:
-            if iconUrlStr.startswith(urlStr):
-                return self.__iconsDB[iconUrlStr]
+        if urlStr in self.__iconsDB:
+            return self.__iconsDB[urlStr]
+        else:
+            for iconUrlStr in self.__iconsDB:
+                if iconUrlStr.startswith(urlStr):
+                    return self.__iconsDB[iconUrlStr]
         
         # try replacing http scheme with https scheme
         url = QUrl(url)
         if url.scheme() == "http":
             url.setScheme("https")
-        urlStr = self.__urlToString(url)
-        for iconUrlStr in self.__iconsDB:
-            if iconUrlStr.startswith(urlStr):
-                return self.__iconsDB[iconUrlStr]
+            urlStr = self.__urlToString(url)
+            if urlStr in self.__iconsDB:
+                return self.__iconsDB[urlStr]
+            else:
+                for iconUrlStr in self.__iconsDB:
+                    if iconUrlStr.startswith(urlStr):
+                        return self.__iconsDB[iconUrlStr]
         
         if scheme == "https":
-            return UI.PixmapCache.getIcon("securityHigh32.png")
+            return UI.PixmapCache.getIcon("securityHigh32")
         else:
-            return UI.PixmapCache.getIcon("defaultIcon.png")
+            return UI.PixmapCache.getIcon("defaultIcon")
     
     def clear(self):
         """
