@@ -36,5 +36,5 @@ class VirusTotalWhoisDialog(QDialog, Ui_VirusTotalWhoisDialog):
         self.headerLabel.setText(
             self.tr("<b>Whois information for domain {0}</b>").format(domain))
         self.headerPixmap.setPixmap(
-            UI.PixmapCache.getPixmap("virustotal.png"))
+            UI.PixmapCache.getPixmap("virustotal"))
         self.whoisEdit.setPlainText(whois)
