@@ -11,8 +11,6 @@ This is the main Python script that performs the necessary initialization
 of the IDE and starts the Qt event loop.
 """
 
-# TODO: remove support for Qt4 and pyside (1)
-
 import sys
 import os
 
@@ -293,6 +291,14 @@ def main():
     if "__PYVENV_LAUNCHER__" in os.environ:
         del os.environ["__PYVENV_LAUNCHER__"]
     
+    # make sure our executable directory (i.e. that of the used Python
+    # interpreter) is included in the executable search path
+    pathList = os.environ["PATH"].split(os.pathsep)
+    exeDir = os.path.dirname(sys.executable)
+    if exeDir not in pathList:
+        pathList.insert(0, exeDir)
+    os.environ["PATH"] = os.pathsep.join(pathList)
+    
     from Toolbox import Startup
     # set the library paths for plugins
     Startup.setLibraryPaths()
